
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.0',
    'branch_nick': 'feature-0-Release__1_23_0_Final_preparation',
    'revision_id': '2fee746b71f157e0bb7d3d7bc919d84c78e86f80',
    'revno': 9923
}
